@@ -1,23 +1,9 @@
 /*
- * kdfconfig.cpp
- *
- * Copyright (c) 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
- *               2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
+    SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 //
 // 1999-11-29 Espen Sand
@@ -59,7 +45,7 @@ KDFConfigWidget::KDFConfigWidget(QWidget *parent, bool init)
         setupUi(this);
 
         QStringList headerLabels;
-        for ( const Column &c : qAsConst(m_columnList))
+        for ( const Column &c : std::as_const(m_columnList))
         {
             headerLabels << c.columnName;
         }
