@@ -1,23 +1,9 @@
 /*
- * kdfwidget.cpp
- *
- * Copyright (c) 1998-2001 Michael Kropfberger <michael.kropfberger@gmx.net>
- *               2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 1998-2001 Michael Kropfberger <michael.kropfberger@gmx.net>
+    SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 //
 // 1999-11-29 Espen Sand
@@ -121,7 +107,7 @@ void KDFWidget::makeColumns( void )
 {
 
     QStringList columns;
-    for (const Column &c : qAsConst(m_columnList)){
+    for (const Column &c : std::as_const(m_columnList)){
         columns << c.columnName;
     }
     m_listModel->setHorizontalHeaderLabels( columns );
@@ -153,7 +139,7 @@ void KDFWidget::applySettings( void )
 
     if( GUI )
     {
-        for (const Column &c : qAsConst(m_columnList)){
+        for (const Column &c : std::as_const(m_columnList)){
             if( !m_listWidget->isColumnHidden( c.number ) )
                 config.writeEntry( c.name, m_listWidget->columnWidth(c.number) );
         }
@@ -184,13 +170,13 @@ void KDFWidget::loadSettings( void )
     if(GUI)
     {
         KConfigGroup config(KSharedConfig::openConfig(), "KDiskFree");
-        for (const Column &c : qAsConst(m_columnList)){
+        for (const Column &c : std::as_const(m_columnList)){
             int width = config.readEntry( c.name, c.defaultWidth );
             m_listWidget->setColumnWidth( c.number, width );
         }
 
         KConfigGroup config_visible(KSharedConfig::openConfig(), "KDFConfig");
-        for (const Column &c : qAsConst(m_columnList)){
+        for (const Column &c : std::as_const(m_columnList)){
             bool visible = config_visible.readEntry( c.name , true );
             m_listWidget->setColumnHidden( c.number, !visible );
         }
@@ -475,7 +461,9 @@ void KDFWidget::contextMenuRequested( const QPoint &p )
             {
                 cmd += QLatin1Char( ' ' ) + KShell::quoteArg(disk->mountPoint());
             }
-            QProcess::startDetached(cmd, QStringList());
+            QStringList argList = cmd.split(QLatin1Char( ' ' ), Qt::SkipEmptyParts);
+            cmd = argList.takeFirst();
+            QProcess::startDetached(cmd, argList);
         }
     }
 
